@@ -5,6 +5,7 @@ import typing
 from types import TracebackType
 from urllib.parse import SplitResult, parse_qsl, urlsplit
 
+from sqlalchemy import text
 from sqlalchemy.engine import RowProxy
 from sqlalchemy.sql import ClauseElement
 
@@ -88,27 +89,35 @@ class Database:
     ) -> None:
         await self.disconnect()
 
-    async def fetch_all(self, query: ClauseElement) -> typing.List[RowProxy]:
+    async def fetch_all(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> typing.List[RowProxy]:
         async with self.connection() as connection:
-            return await connection.fetch_all(query=query)
+            return await connection.fetch_all(query, values)
 
-    async def fetch_one(self, query: ClauseElement) -> RowProxy:
+    async def fetch_one(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> RowProxy:
         async with self.connection() as connection:
-            return await connection.fetch_one(query=query)
+            return await connection.fetch_one(query, values)
 
-    async def execute(self, query: ClauseElement, values: dict = None) -> typing.Any:
+    async def execute(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> typing.Any:
         async with self.connection() as connection:
-            return await connection.execute(query=query, values=values)
+            return await connection.execute(query, values)
 
-    async def execute_many(self, query: ClauseElement, values: list) -> None:
+    async def execute_many(
+        self, query: typing.Union[ClauseElement, str], values: list
+    ) -> None:
         async with self.connection() as connection:
-            return await connection.execute_many(query=query, values=values)
+            return await connection.execute_many(query, values)
 
     async def iterate(
-        self, query: ClauseElement
+        self, query: typing.Union[ClauseElement, str], values: dict = None
     ) -> typing.AsyncGenerator[RowProxy, None]:
         async with self.connection() as connection:
-            async for record in connection.iterate(query):
+            async for record in connection.iterate(query, values):
                 yield record
 
     def connection(self) -> "Connection":
@@ -156,22 +165,31 @@ class Connection:
             if self._connection_counter == 0:
                 await self._connection.release()
 
-    async def fetch_all(self, query: ClauseElement) -> typing.Any:
-        return await self._connection.fetch_all(query=query)
+    async def fetch_all(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> typing.Any:
+        return await self._connection.fetch_all(self._build_query(query, values))
 
-    async def fetch_one(self, query: ClauseElement) -> typing.Any:
-        return await self._connection.fetch_one(query=query)
+    async def fetch_one(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> typing.Any:
+        return await self._connection.fetch_one(self._build_query(query, values))
 
-    async def execute(self, query: ClauseElement, values: dict = None) -> typing.Any:
-        return await self._connection.execute(query, values)
+    async def execute(
+        self, query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> typing.Any:
+        return await self._connection.execute(self._build_query(query, values))
 
-    async def execute_many(self, query: ClauseElement, values: list) -> None:
-        await self._connection.execute_many(query, values)
+    async def execute_many(
+        self, query: typing.Union[ClauseElement, str], values: list
+    ) -> None:
+        queries = [self._build_query(query, values_set) for values_set in values]
+        await self._connection.execute_many(queries)
 
     async def iterate(
-        self, query: ClauseElement
+        self, query: typing.Union[ClauseElement, str], values: dict = None
     ) -> typing.AsyncGenerator[typing.Any, None]:
-        async for record in self._connection.iterate(query):
+        async for record in self._connection.iterate(self._build_query(query, values)):
             yield record
 
     def transaction(self, *, force_rollback: bool = False) -> "Transaction":
@@ -181,6 +199,19 @@ class Connection:
     def raw_connection(self) -> typing.Any:
         return self._connection.raw_connection
 
+    @staticmethod
+    def _build_query(
+        query: typing.Union[ClauseElement, str], values: dict = None
+    ) -> ClauseElement:
+        if isinstance(query, str):
+            query = text(query)
+
+            return query.bindparams(**values) if values is not None else query
+        elif values:
+            return query.values(**values)
+
+        return query
+
 
 class Transaction:
     def __init__(self, connection: Connection, force_rollback: bool) -> None:
